"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createNetworkSignal = exports.createUserDefinedSignal = exports.createNavigationSignal = exports.createInteractionSignal = exports.createInstrumentationSignal = void 0;
const normalize_url_1 = require("../lib/normalize-url");
const page_data_1 = require("../lib/page-data");
/**
 * Factories
 */
const createInstrumentationSignal = (rawEvent) => {
    return {
        type: 'instrumentation',
        data: {
            page: (0, page_data_1.getPageData)(),
            rawEvent,
        },
    };
};
exports.createInstrumentationSignal = createInstrumentationSignal;
const createInteractionSignal = (data) => {
    return {
        type: 'interaction',
        data: {
            ...data,
            page: (0, page_data_1.getPageData)(),
        },
    };
};
exports.createInteractionSignal = createInteractionSignal;
const createNavigationSignal = (data) => {
    return {
        type: 'navigation',
        data: {
            ...data,
            page: (0, page_data_1.getPageData)(),
        },
    };
};
exports.createNavigationSignal = createNavigationSignal;
const createUserDefinedSignal = (data) => {
    return {
        type: 'userDefined',
        data: {
            ...data,
            page: (0, page_data_1.getPageData)(),
        },
    };
};
exports.createUserDefinedSignal = createUserDefinedSignal;
const createNetworkSignal = (data, metadata) => {
    return {
        type: 'network',
        data: {
            ...data,
            url: (0, normalize_url_1.normalizeUrl)(data.url),
            page: (0, page_data_1.getPageData)(),
        },
        metadata: metadata ?? {
            filters: {
                allowed: [],
                disallowed: [],
            },
        },
    };
};
exports.createNetworkSignal = createNetworkSignal;
//# sourceMappingURL=factories.js.map